;**************************************************************************
;* FileName	: TMRX.ASM
;* Date 	: 20.08.2003
;* File version : v1.00
								list l=0
;* Author	: MIKO, Imre
;* Company	:
;* Homepage	: http://majki.fw.hu
;* E-mail	: majki@fw.hu
;*
;*-------------------------------------------------------------------------
;*
;* Description	: test for TMRx module
;*		  ==================================
;*		 
;*
;*
;*-------------------------------------------------------------------------
;*
;* Connections	:	       _______	 _______
;*			      |       \_/	|
;*		     -reset ==| -MCLR	    RB7 |== n.c.
;*		       n.c. ==| RA0	    RB6 |== n.c.
;*		       n.c. ==| RA1	    RB5 |== n.c.
;*		       n.c. ==| RA2	    RB4 |== n.c.
;*		       n.c. ==| RA3	    RB3 |== n.c.
;*		       n.c. ==| RA4	    RB2 |== n.c.
;*		       n.c. ==| RA5	    RB1 |== n.c.
;*		        GND ==| Vss	    RB0 |== n.c.
;*		    quartz1 ==| OSC1	    Vdd |== +5V
;*		    quartz2 ==| OSC2	    Vss |== GND
;*		       n.c. ==| RC0	    RC7 |== n.c.
;*		       n.c. ==| RC1	    RC6 |== n.c.
;*		       n.c. ==| RC2	    RC5 |== n.c.
;*		       n.c. ==| RC3	    RC4 |== n.c.
;*			      |_________________|
;*				   PIC16F872 
;*
;*-------------------------------------------------------------------------
;*
;* Resource	: Ports 	  :    xx /   22 pin   (   %)
;*		  Data memory	  :    xx /  128 byte  (   %)
;*		  Prog memory	  :   xxx / 2048 word  (   %)
;*		  EEPROM	  :    xx /   64 byte  (   %)
;*		  Timers	  : 
;*		  Interrupt	  : 
;*		  CCP		  :
;*		  MSSP		  :
;*		  AD		  :
;*
;**************************************************************************
;* Revision History:
;*
;* 1.00	  20/08/2003 	Initial Release
;*
;**************************************************************************

	list	p=16f872, r=dec, l=0

;***** INCLUDES ***********************************************************

	include "p16f872.inc"
	include "..\..\modules\base.inc"

;***** CONFIG ************************************************************

CFG_1	EQU 	_XT_OSC & _WDT_OFF & _PWRTE_ON & _BODEN_ON & _LVP_OFF
CFG_2	EQU	_CPD_OFF & _WRT_ENABLE_OFF & _DEBUG_OFF & _CP_OFF

	__CONFIG CFG_1 & CFG_2
	__IDLOCS 0100h			; version

	EXPAND_MACROS	EXP_COND	; macro expansion mode
	MULTIPAGE	1, 2048, 4	; support for multipage program memory

;***** DEFINES ************************************************************
;#define DEBUG				; for some debug message
;#define NO_DELAY			; for fast simulation
;#define NO_RS232			; for fast simulation
;#define NO_EE24

xtal_freq	EQU	20 MHz	  	; crystal frequency
core_freq	EQU	xtal_freq/4	; core operating frequency


; ----- porta -------------------------------------------------------------

#define		PORTA_0		PORTA,0		; free
#define		PORTA_1		PORTA,1		; free
#define		PORTA_2		PORTA,2		; free
#define		PORTA_3		PORTA,3		; free
#define		PORTA_4		PORTA,4		; free (open drain!)
#define		PORTA_5		PORTA,5		; free

; ----- portb -------------------------------------------------------------

#define		PORTB_0		PORTB,0		; free
#define		PORTB_1		PORTB,1		; free
#define		PORTB_2		PORTB,2		; free
#define		PORTB_3		PORTB,3		; free
#define		PORTB_4		PORTB,4		; free
#define		PORTB_5		PORTB,5		; free
#define		PORTB_6		PORTB,6		; free
#define		PORTB_7		PORTB,7		; free

; ----- portc -------------------------------------------------------------

#define		PORTC_0		PORTC,0		; free
#define		PORTC_1		PORTC,1		; free
#define		PORTC_2		PORTC,2		; free
#define		PORTC_3		PORTC,3		; free
#define		PORTC_4		PORTC,4		; free
#define		PORTC_5		PORTC,5		; free
#define		PORTC_6		PORTC,6		; free
#define		PORTC_7		PORTC,7		; free

;***** MACROS *************************************************************

	include "..\..\modules\tmrx.mac"


;***** CONSTANT DEFINITIONS ***********************************************

option_val	EQU	00000010b	; Timer source : intclk / 8
trisa_val	EQU	00111111b	; TRISA value (all input)
trisb_val	EQU	11111111b	; TRISB value (all input)
trisc_val	EQU	11111111b	; TRISC value (all input)
adcon0_val	EQU	00000000b	; ADCON0 value (AD off)
adcon1_val	EQU	00000110b	; ADCON1 value (add digital input)
intcon_val	EQU	00100000b	; Interrupt control




;***** VARIABLE DEFINITIONS ***********************************************
	cblock	70h			; common RAM
		icd_temp		; reserved for ICD
		w_temp			; variable used for context saving
		status_temp		; variable used for context saving
		fsr_temp		; variable used for context saving
	endc

;--------------------------------------------------------------------------
	cblock	0BBh
		icd_temp2:5		; reserved for ICD
	endc

;--------------------------------------------------------------------------
	cblock	20h

		TEMP			; dummy register

	endc




;***** ENTRY POINT ********************************************************
		ORG	000h		; processor reset vector
		nop
		clrwdt
		clrf	STATUS
		goto	start


;***** IT HANDLER *********************************************************
;* Interrupt handler
;* <comment>
;**************************************************************************
		ORG	004h		; interrupt vector location
		movwf	w_temp		; save off current W register contents
		swapf	STATUS,w	; move STATUS register into W register
		movwf	status_temp	; save off contents of STATUS register

		movf	FSR,w		; save FSR
		movwf	fsr_temp
;--------------------------------------------------------------------------

		; <IT Code>

;--------------------------------------------------------------------------
		movf	fsr_temp,w	; restore FSR
		movwf	FSR

		swapf	status_temp,w	; retrieve copy of STATUS register
		movwf	STATUS		; restore pre-isr STATUS register contents
		swapf	w_temp,f
		swapf	w_temp,w	; restore pre-isr W register contents
		retfie			; return from interrupt




;***** REAL PROGRAM START *************************************************
start
;----- set configuration --------------------------------------------------
		clrf	PORTA		; clear latch
		clrf	PORTB		; clear latch
		clrf	PORTC		; clear latch
		bank1
		ERRORLEVEL -302
		movlw	option_val
		movwf	OPTION_REG	; set OPTION_REG
		movlw	trisa_val
		movwf	TRISA		; set TRISA
		movlw	trisb_val
		movwf	TRISB		; set TRISB
		movlw	trisc_val
		movwf	TRISC		; set TRISC
		movlw	adcon1_val	
		movwf	ADCON1		; set ADCON1
		bank0
		ERRORLEVEL +302
		movlw	adcon0_val	
		movwf	ADCON0		; set ADCON0
		movlw	intcon_val	
		movwf	INTCON		; set INTCON


;----- module inits  ------------------------------------------------------

		TMR0_INIT 32
		TMR1_INIT 4
		TMR2_INIT 4



		nop
		TMR0_WAIT 1000 Microsec
		nop
		TMR0_WAIT 100 Microsec
		nop
		TMR0_WAIT 1 Microsec
		nop

		TMR1_WAIT 1000 Microsec
		nop
		TMR1_WAIT 100 Microsec
		nop
		TMR1_WAIT 1 Microsec
		nop

		TMR2_WAIT 1000 Microsec
		nop
		TMR2_WAIT 100 Microsec
		nop
		TMR2_WAIT 1 Microsec
		nop
	


		movlw	3	;3E8
		movwf	tmr1hi
		movlw	0E8h
		TMR1_STARTW
ide1		TMR1_NOTOUT	ide1
		

		nop


		movlw	3	;3E8
		movwf	tmr2hi
		movlw	0E8h
		TMR2_STARTW
ide2		TMR2_NOTOUT	ide2


		nop


;----- main cycle  --------------------------------------------------------


main_cycle	nop

		; <code>

		goto	main_cycle






;***** SUB1 ***************************************************************
;* 
;* Input :              		; 
;* Output:  				; 
;* Clock :   
;**************************************************************************

sub1 


		return

;***** INCLUDES ***********************************************************

	include "..\..\modules\tmrx.inc"


;**************************************************************************
	end				  ; end of program








